#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 warp-tls
version:              3.4.9
visibility:           public
id:                   warp-tls-3.4.9-Lpku3dbimGL18jVk9SZf7R
key:                  warp-tls-3.4.9-Lpku3dbimGL18jVk9SZf7R
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             HTTP over TLS support for Warp via the TLS package
description:
    SSLv1 and SSLv2 are obsoleted by IETF.
    We should use TLS 1.2 (or TLS 1.1 or TLS 1.0 if necessary).
    HTTP/2 can be negotiated by ALPN.
    API docs and the README are available at
    <http://www.stackage.org/package/warp-tls>.

category:             Web, Yesod
abi:                  8a3ff7e4ad2fd46695577d411d2076d3
exposed:              True
exposed-modules:
    Network.Wai.Handler.WarpTLS Network.Wai.Handler.WarpTLS.Internal

import-dirs:          /usr/lib/ghc-9.6.6/site-local/warp-tls-3.4.9
library-dirs:         /usr/lib/ghc-9.6.6/site-local/warp-tls-3.4.9
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/warp-tls-3.4.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-warp-tls
hs-libraries:         HSwarp-tls-3.4.9-Lpku3dbimGL18jVk9SZf7R
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    network-3.1.4.0-9dONp0onFcbAlDBEoFNGkb
    recv-0.1.1-KedjKNp6OFcEQzyL6HxX5O
    streaming-commons-0.2.3.1-CD29ujDIwjv88YwbpR0Txf
    tls-2.0.6-LsaqvatMXqbG9c8xVTmRsq
    tls-session-manager-0.0.6-FDWUP2LXstS33q2SDobd70
    unliftio-0.2.25.1-KBv4DTXvafxB4kek08uChL
    wai-3.2.4-3XyCh5m71lWJYF48VLLZUp warp-3.4.0-9HslBeBY1wf9o4ROK9xeo9

haddock-interfaces:   /usr/share/doc/haskell-warp-tls/html/warp-tls.haddock
haddock-html:         /usr/share/doc/haskell-warp-tls/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

